@@ -11,12 +11,12 @@ LMDB_MAP_SIZE = 100 * 1024 * 1024 * 1024
 class DocStorage:
     """The backend storage engine of Documents"""
 
-    def __init__(self, path: Union[str, Path], serialize_config: Dict = {}):
+    def __init__(self, path: Union[str, Path], serialize_config: Dict = {}, lock: bool = True):
         self._path = path
-        self._env = self._open(path)
+        self._env = self._open(path, lock=lock)
         self._serialize_config = serialize_config
 
-    def _open(self, db_path: Union[str, Path]):
+    def _open(self, db_path: Union[str, Path], lock: bool = True):
         return lmdb.Environment(
             str(self._path),
             map_size=LMDB_MAP_SIZE,
@@ -33,7 +33,7 @@ class DocStorage:
             max_readers=126,
             max_dbs=0,  # means only one db
             max_spare_txns=1,
-            lock=True,
+            lock=lock,
         )
 
     def insert(self, docs: 'DocumentArray'):
